@@ -1,4 +1,4 @@
-use crate::common::*;
+use super::*;
 
 use CompileErrorKind::*;
 
@@ -82,6 +82,17 @@ impl<'src: 'run, 'run> AssignmentResolver<'src, 'run> {
           self.resolve_expression(a)?;
           self.resolve_expression(b)
         }
+        Thunk::BinaryPlus {
+          args: ([a, b], rest),
+          ..
+        } => {
+          self.resolve_expression(a)?;
+          self.resolve_expression(b)?;
+          for arg in rest {
+            self.resolve_expression(arg)?;
+          }
+          Ok(())
+        }
         Thunk::Ternary {
           args: [a, b, c], ..
         } => {
@@ -90,7 +101,7 @@ impl<'src: 'run, 'run> AssignmentResolver<'src, 'run> {
           self.resolve_expression(c)
         }
       },
-      Expression::Concatination { lhs, rhs } => {
+      Expression::Concatenation { lhs, rhs } | Expression::Join { lhs, rhs } => {
         self.resolve_expression(lhs)?;
         self.resolve_expression(rhs)
       }
